==> selenium-selenium-4.31.0.gh.tar.gz: selenium-selenium-4.31.0/dotnet/src/webdriver/LogType.cs <==
// <copyright file="LogType.cs" company="Selenium Committers">
// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
// </copyright>

namespace OpenQA.Selenium
{
    /// <summary>
    /// Class containing names of common log types.
    /// </summary>
    public static class LogType
    {
        /// <summary>
        /// Log messages from the client language bindings.
        /// </summary>
        public static readonly string Client = "client";

        /// <summary>
        /// Logs from the current WebDriver instance.
        /// </summary>
        public static readonly string Driver = "driver";

        /// <summary>
        /// Logs from the browser.
        /// </summary>
        public static readonly string Browser = "browser";

        /// <summary>
        /// Logs from the server.
        /// </summary>
        public static readonly string Server = "server";

        /// <summary>
        /// Profiling logs.
        /// </summary>
        public static readonly string Profiler = "profiler";

        /// <summary>
        /// Performance logs.
        /// </summary>
        public static readonly string Performance = "performance";
    }
}

==> selenium-selenium-4.37.0.gh.tar.gz: selenium-selenium-4.37.0/dotnet/src/webdriver/LogType.cs <==
// <copyright file="LogType.cs" company="Selenium Committers">
// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
// </copyright>

namespace OpenQA.Selenium;

/// <summary>
/// Class containing names of common log types.
/// </summary>
public static class LogType
{
    /// <summary>
    /// Log messages from the client language bindings.
    /// </summary>
    public static readonly string Client = "client";

    /// <summary>
    /// Logs from the current WebDriver instance.
    /// </summary>
    public static readonly string Driver = "driver";

    /// <summary>
    /// Logs from the browser.
    /// </summary>
    public static readonly string Browser = "browser";

    /// <summary>
    /// Logs from the server.
    /// </summary>
    public static readonly string Server = "server";

    /// <summary>
    /// Profiling logs.
    /// </summary>
    public static readonly string Profiler = "profiler";

    /// <summary>
    /// Performance logs.
    /// </summary>
    public static readonly string Performance = "performance";
}
